Crate macos_shortcuts

Crate macos_shortcuts 

This crate enables access to Apple Shortcuts for Mac.

The crate currently supports loading Shortcuts that have been defined using the Shortcuts app.

Structs

Shortcut
An object representing a single shortcut in the Shortcuts app