Shortcut

Struct Shortcut 

pub struct Shortcut { /* private fields */ }
An object representing a single shortcut in the Shortcuts app

Implementations

Source

impl Shortcut

pub fn load() -> Result<Vec<Shortcut>, Box<dyn Error>>

Load the current set of shortcuts defined in the Shortcuts app. This will load all shortcuts regardless of folder.

This method currently uses a small AppleScript snippet and executes this using osascript.

pub fn load_folder(folder: &str) -> Result<Vec<Shortcut>, Box<dyn Error>>

Load the current set of shortcuts defined in the Shortcuts app in the given folder.

This method currently uses a small AppleScript snippet and executes this using osascript.

pub fn folder(&self) -> Option<&str>

Get the folder name that this shortcut is contained within or None if the shortcut isn’t in a folder

pub fn icon(&self) -> &DynamicImage

Get the icon defined for this shortcut. The dimensions of the icon are driven by the AppleScript and the Shortcuts app used to load the data

pub fn id(&self) -> &str

The unique id of the shortcut. This is used to execute the shortcut to avoid issues with duplicate named shortcuts

pub fn name(&self) -> &str

The name of the shortcuts executable

pub fn run(&self, input: Option<&[u8]>) -> Result<Vec<u8>, Box<dyn Error>>

Attempt to run the shortcut, using temporary files for input and output using the shortcuts executable