pub struct Shortcut { /* private fields */ }Expand description
An object representing a single shortcut in the Shortcuts app
Implementations
Sourceimpl Shortcut
impl Shortcut
Sourcepub fn load() -> Result<Vec<Shortcut>, Box<dyn Error>>
pub fn load() -> Result<Vec<Shortcut>, Box<dyn Error>>
Load the current set of shortcuts defined in the Shortcuts app. This will load all shortcuts regardless of folder.
This method currently uses a small AppleScript snippet and executes this using osascript.
Sourcepub fn load_folder(folder: &str) -> Result<Vec<Shortcut>, Box<dyn Error>>
pub fn load_folder(folder: &str) -> Result<Vec<Shortcut>, Box<dyn Error>>
Load the current set of shortcuts defined in the Shortcuts app in the given folder.
This method currently uses a small AppleScript snippet and executes this using osascript.
Sourcepub fn folder(&self) -> Option<&str>
pub fn folder(&self) -> Option<&str>
Get the folder name that this shortcut is contained within or None
if the shortcut isn’t in a folder
Sourcepub fn icon(&self) -> &DynamicImage
pub fn icon(&self) -> &DynamicImage
Get the icon defined for this shortcut. The dimensions of the icon are driven by the AppleScript and the Shortcuts app used to load the data